aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--HOWTO_chandra_acis_process.txt6
-rwxr-xr-xscripts/ciao_bkg_spectra.sh (renamed from scripts/ciao_bkg_spectra_v4.sh)0
-rwxr-xr-xscripts/ciao_blanksky.sh (renamed from scripts/ciao_blanksky_v4.sh)0
-rwxr-xr-xscripts/ciao_deproj_spectra.sh (renamed from scripts/ciao_deproj_spectra_v8.sh)0
-rwxr-xr-xscripts/ciao_expcorr.sh (renamed from scripts/ciao_expcorr_only.sh)8
-rwxr-xr-xscripts/ciao_expcorr_sbp.sh (renamed from scripts/ciao_expcorr_sbp_v4.sh)9
-rwxr-xr-xscripts/ciao_genregs.sh (renamed from scripts/ciao_genregs_v1.sh)0
-rwxr-xr-xscripts/ciao_procevt.sh (renamed from scripts/ciao_procevt_v2.sh)5
-rwxr-xr-xscripts/ciao_r500avgt.sh (renamed from scripts/ciao_r500avgt_v3.sh)0
-rwxr-xr-xscripts/ciao_sbp.sh (renamed from scripts/ciao_sbp_v3.1.sh)0
10 files changed, 17 insertions, 11 deletions
diff --git a/HOWTO_chandra_acis_process.txt b/HOWTO_chandra_acis_process.txt
index 95a9f0a..ec46110 100644
--- a/HOWTO_chandra_acis_process.txt
+++ b/HOWTO_chandra_acis_process.txt
@@ -37,7 +37,7 @@ nH tool: https://heasarc.gsfc.nasa.gov/cgi-bin/Tools/w3nh/w3nh.pl
(1) $ chandra_repro indir=. outdir=repro verbose=2
(2) $ cd repro; mkdir -p evt bkg img spc/profile mass;
(3) $ cd evt; ln -s ../acis*evt2.fits .;
- (4) $ ciao_procevt2.sh
+ (4) $ ciao_procevt.sh
(5) $ cd ../bkg; ln -s ../evt/evt2*_clean.fits .;
(6) $ ciao_blanksky_v4.sh
(7) ds9 open 'evt2*_clean.fits'; select edge region as the
@@ -54,7 +54,7 @@ nH tool: https://heasarc.gsfc.nasa.gov/cgi-bin/Tools/w3nh/w3nh.pl
(12) cd ../img; ln -s ../evt/evt2*_clean.fits .;
(13) ds9 open 'evt2*_clean.fits', select the center of cluster,
save the region as 'center.reg'
-(14) $ ciao_genregs_v1.sh reg_in=center.reg
+(14) $ ciao_genregs_v1.sh reg_in=center.reg bkgd=<bkgd>
(15) $ cd ../spc/profile;
$ ln -s ../../evt/evt2*_clean.fits .;
$ ln -s ../../bkg/bkgcorr_blanksky_lbkg.pi .; (maybe 'lbkg.pi')
@@ -87,7 +87,7 @@ nH tool: https://heasarc.gsfc.nasa.gov/cgi-bin/Tools/w3nh/w3nh.pl
z <redshift>
temp <avg_temp>
abund <avg_abund>
-(23) $ ciao_expcorr_sbp_v4.sh basedir=.. nh=<nh> z=<redshift> temp=<avg_temp> abund=<avg_abund>
+(23) $ ciao_expcorr_sbp.sh basedir=.. nh=<nh> z=<redshift> temp=<avg_temp> abund=<avg_abund>
## --------------------------------------------------------
(24) $ cd ../mass; clean_massdir.sh;
diff --git a/scripts/ciao_bkg_spectra_v4.sh b/scripts/ciao_bkg_spectra.sh
index b4dbbbd..b4dbbbd 100755
--- a/scripts/ciao_bkg_spectra_v4.sh
+++ b/scripts/ciao_bkg_spectra.sh
diff --git a/scripts/ciao_blanksky_v4.sh b/scripts/ciao_blanksky.sh
index da1d6f6..da1d6f6 100755
--- a/scripts/ciao_blanksky_v4.sh
+++ b/scripts/ciao_blanksky.sh
diff --git a/scripts/ciao_deproj_spectra_v8.sh b/scripts/ciao_deproj_spectra.sh
index abebc7c..abebc7c 100755
--- a/scripts/ciao_deproj_spectra_v8.sh
+++ b/scripts/ciao_deproj_spectra.sh
diff --git a/scripts/ciao_expcorr_only.sh b/scripts/ciao_expcorr.sh
index f4d390b..701ba01 100755
--- a/scripts/ciao_expcorr_only.sh
+++ b/scripts/ciao_expcorr.sh
@@ -306,7 +306,7 @@ printf "generate skyfov ...\n"
SKYFOV="_skyfov.fits"
[ -e "${SKYFOV}" ] && rm -fv ${SKYFOV}
punlearn skyfov
-skyfov infile="${EVT}" outfile="${SKYFOV}" clobber=yes
+skyfov infile="${EVT}" outfile="${SKYFOV}" aspect="@${ASOLIS}" clobber=yes
## filter by energy band & make image
printf "filter out events in energy band: \`${ENG_RANGE}' ...\n"
@@ -375,11 +375,11 @@ else
maskfile="${MSK}" clobber=yes
## make symbolic links
# clipped counts image
- ln -sv "${ROOTNAME}*band*thresh.img" "${IMG_ORIG%.fits}_thresh.fits"
+ ln -svf ${ROOTNAME}*band*thresh.img ${IMG_ORIG%.fits}_thresh.fits
# clipped exposure map
- ln -sv "${ROOTNAME}*band*thresh.expmap" "${EXPMAP}"
+ ln -svf ${ROOTNAME}*band*thresh.expmap ${EXPMAP}
# exposure-corrected image
- ln -sv "${ROOTNAME}*band*flux.img" "${IMG_EXPCORR}"
+ ln -svf ${ROOTNAME}*band*flux.img ${IMG_EXPCORR}
fi
## main }}}
diff --git a/scripts/ciao_genregs_v1.sh b/scripts/ciao_genregs.sh
index 643acba..643acba 100755
--- a/scripts/ciao_genregs_v1.sh
+++ b/scripts/ciao_genregs.sh
diff --git a/scripts/ciao_procevt_v2.sh b/scripts/ciao_procevt.sh
index 6cfe45d..d73bfaf 100755
--- a/scripts/ciao_procevt_v2.sh
+++ b/scripts/ciao_procevt.sh
@@ -19,6 +19,9 @@
###########################################################
## ChangeLogs:
+## v2.2, 2014/10/30, Weitian LI
+## small fix to the generation of chips script:
+## changed '>>' to '>'
## v2.1, 2012/08/16, LIweitiaNux
## improve invoke `chips', run it in a separate terminal
###########################################################
@@ -160,7 +163,7 @@ dmextract infile="${EVT2_RMSRCS}[exclude sky=region(${LC_REG})][bin time=::200]"
LC_SCRIPT="_${LC%.lc}.chips"
LC_SCALE=1.2
GTI="${LC%.lc}.gti"
-cat >> ${LC_SCRIPT} << _EOF_
+cat > ${LC_SCRIPT} << _EOF_
from lightcurves import *
lc_clean("${LC}")
lc_clean("${LC}", scale=${LC_SCALE}, outfile="${GTI}")
diff --git a/scripts/ciao_r500avgt_v3.sh b/scripts/ciao_r500avgt.sh
index 9a8dffd..9a8dffd 100755
--- a/scripts/ciao_r500avgt_v3.sh
+++ b/scripts/ciao_r500avgt.sh
diff --git a/scripts/ciao_sbp_v3.1.sh b/scripts/ciao_sbp.sh
index d111b7f..d111b7f 100755
--- a/scripts/ciao_sbp_v3.1.sh
+++ b/scripts/ciao_sbp.sh
diff --git a/scripts/ciao_expcorr_sbp_v4.sh b/scripts/ciao_expcorr_sbp.sh
index 861c6dd..fc1e5ed 100755
--- a/scripts/ciao_expcorr_sbp_v4.sh
+++ b/scripts/ciao_expcorr_sbp.sh
@@ -4,9 +4,12 @@ export LC_COLLATE=C
#####################################################################
## make exposure map and exposure-corrected image
## extract surface brightness profile (revoke 'ciao_sbp_v3.1.sh')
##
## ChangeLogs:
+## v4.1, 2014/10/30, Weitian LI
+## updated 'EXPCORR_SCRIPT' & 'EXTRACT_SBP_SCRIPT',
+## removed version number in scripts filename.
## v4, 2013/10/12, LIweitiaNux
## split out the 'generate regions' parts -> 'ciao_genreg_v1.sh'
## v3, 2013/05/03, LIweitiaNux
@@ -15,8 +18,8 @@ export LC_COLLATE=C
SCRIPT_PATH=`readlink -f $0`
SCRIPT_DIR=`dirname ${SCRIPT_PATH}`
-EXPCORR_SCRIPT="ciao_expcorr_only.sh"
-EXTRACT_SBP_SCRIPT="ciao_sbp_v3.1.sh"
+EXPCORR_SCRIPT="ciao_expcorr.sh"
+EXTRACT_SBP_SCRIPT="ciao_sbp.sh"
## about, used in `usage' {{{
VERSION="v4"
@@ -4,9 +4,12 @@ export LC_COLLATE=C
#####################################################################
## make exposure map and exposure-corrected image
-## extract surface brightness profile (revoke 'ciao_sbp_v3.1.sh')
+## extract surface brightness profile (revoke 'ciao_sbp.sh')
##
## ChangeLogs: